Subject: [bug#69978] [PATCH 4/4] gnu: python-celery: Update to 5.3.6.

From: Vinicius Monego <[email-masked]>
Date: Sun, 24 Mar 2024 11:20:10 +0000

* gnu/packages/python-xyz.scm (python-celery): Update to 5.3.6.
[build-system]: Use pyproject-build-system.
[arguments]: Replace pytz with tzdata in the relax-requirements phase. Do not
override the check phase, skip tests in #:test-flags instead.
[native-inputs]: Add python-pytest-click.
[propagated-inputs]: Add python-tzdata. Remove python-pytz.

Change-Id: I4cb6a1c6712d5b54f4d9a6731447e9459e8ff81a
---
 gnu/packages/python-xyz.scm | 43 +++++++++++++++++--------------------
 1 file changed, 20 insertions(+), 23 deletions(-)

diff --git a/gnu/packages/python-xyz.scm b/gnu/packages/python-xyz.scm
index 9021b9d9db..37f952e54e 100644
--- a/gnu/packages/python-xyz.scm
+++ b/gnu/packages/python-xyz.scm
@@ -18972,34 +18972,30 @@ (define-public python-billiard
 (define-public python-celery
   (package
     (name "python-celery")
-    (version "5.2.6")
+    (version "5.3.6")
     (source
      (origin
        (method url-fetch)
        (uri (pypi-uri "celery" version))
        (sha256
-        (base32 "109lcqarrbmh95sk1dm4yxayq1h3i27f4w23ndk64mqgyfnqqffi"))))
-    (build-system python-build-system)
+        (base32 "1fdacw13ij94s59l6lspl09iv6fc8h1p6399jz1h00kwfcfwf347"))))
+    (build-system pyproject-build-system)
     (arguments
-     '(#:phases
-       (modify-phases %standard-phases
-         (add-after 'unpack 'relax-requirements
-           (lambda _
-             (substitute* "requirements/default.txt"
-               (("pytz.*")
-                "pytz\n"))))
-         (replace 'check
-           (lambda* (#:key tests? #:allow-other-keys)
-             (when tests?
-               (invoke "python" "-m" "pytest" "t"
-                       "--ignore" "t/integration" ;hangs tests
-                       ;; The MongoDB backend test appears to expect an older
-                       ;; version of MongoDB which provided its own bson
-                       ;; module, fails with " AttributeError: module 'bson'
-                       ;; has no attribute 'encode'".
-                       "--ignore" "t/unit/backends/test_mongodb.py"
-                       ;; AssertionErrors
-                       "-k" "not test_check_privileges_no_fchown ")))))))
+     (list
+      ;; The MongoDB backend test appears to expect an older
+      ;; version of MongoDB which provided its own bson
+      ;; module, fails with " AttributeError: module 'bson'
+      ;; has no attribute 'encode'".
+      #:test-flags #~(list "--ignore" "t/unit/backends/test_mongodb.py"
+                           ;; AssertionError.
+                           "-k" "not test_check_privileges_no_fchown")
+      #:phases #~(modify-phases %standard-phases
+                   ;; Celery requires tzdata >= 2022.7, we have 2022.1.
+                   (add-after 'unpack 'relax-requirements
+                     (lambda _
+                       (substitute* "requirements/default.txt"
+                         (("tzdata.*")
+                          "tzdata\n")))))))
     (native-inputs
      (list python-case
            python-dnspython
@@ -19009,6 +19005,7 @@ (define-public python-celery
            python-msgpack
            python-pytest                ;for pytest-subtests
            python-pytest-celery
+           python-pytest-click
            python-pytest-subtests
            python-pytest-timeout
            python-toml))
@@ -19019,7 +19016,7 @@ (define-public python-celery
            python-click-plugins
            python-click-repl
            python-kombu
-           python-pytz
+           python-tzdata
            python-vine))
     (home-page "https://celeryproject.org")
     (synopsis "Distributed Task Queue")
-- 
2.39.2